@@ -18,7 +18,7 @@ import (
 // dbName specifies the database name to be used for sqlite.
 // downloadPath specifies the folder where the downloaded nested bundle(s) will
 // be stored.
-func NewLoader(kubeconfig string, dbName string, downloadPath string, logger *logrus.Entry, legacy bool) (*AppregistryLoader, error) {
+func NewLoader(kubeconfig string, dbName string, downloadPath string, logger *logrus.Entry) (*AppregistryLoader, error) {
 	kubeClient, err := NewKubeClient(kubeconfig, logger)
 	if err != nil {
 		return nil, err
@@ -29,20 +29,8 @@ func NewLoader(kubeconfig string, dbName string, downloadPath string, logger *lo
 		return nil, err
 	}
 
-	var specifier OperatorSourceSpecifier
-	if legacy {
-		logger.Info("operator source CR is being used.")
-		p, err := NewOperatorSourceCRSpecifier(kubeconfig, logger)
-		if err != nil {
-			return nil, err
-		}
-
-		specifier = p
-	} else {
-		specifier = &registrySpecifier{}
-	}
-
-	decoder, err := NewManifestDecoder(logger, downloadPath)
+	specifier := &registrySpecifier{}
+	decoder, err := NewManifestDecoder(logger)
 	if err != nil {
 		return nil, err
 	}
@@ -56,17 +44,19 @@ func NewLoader(kubeconfig string, dbName string, downloadPath string, logger *lo
 			logger:     logger,
 			kubeClient: *kubeClient,
 		},
-		decoder: decoder,
-		loader:  loader,
+		downloadPath: downloadPath,
+		decoder:      decoder,
+		loader:       loader,
 	}, nil
 }
 
 type AppregistryLoader struct {
-	logger     *logrus.Entry
-	input      *inputParser
-	downloader *downloader
-	decoder    *manifestDecoder
-	loader     *dbLoader
+	logger       *logrus.Entry
+	input        *inputParser
+	downloader   *downloader
+	downloadPath string
+	decoder      *manifestDecoder
+	loader       *dbLoader
 }
 
 func (a *AppregistryLoader) Load(csvSources []string, csvPackages string) (registry.Query, error) {
@@ -96,7 +86,7 @@ func (a *AppregistryLoader) Load(csvSources []string, csvPackages string) (regis
 
 	// The set of operator manifest(s) downloaded is a collection of both
 	// flattened single file yaml and nested operator bundle(s).
-	result, err := a.decoder.Decode(rawManifests)
+	result, err := a.decoder.Decode(rawManifests, a.downloadPath)
 	if err != nil {
 		errs = append(errs, fmt.Errorf("error decoding manifest: %s", err))
 	}
@@ -106,18 +96,8 @@ func (a *AppregistryLoader) Load(csvSources []string, csvPackages string) (regis
 
 	a.logger.Infof("decoded %d flattened and %d nested operator manifest(s)", result.FlattenedCount, result.NestedCount)
 
-	if result.Flattened != nil {
-		a.logger.Info("loading flattened operator manifest(s) into sqlite")
-		if err := a.loader.LoadFlattenedToSQLite(result.Flattened); err != nil {
-			errs = append(errs, err)
-		}
-	}
-
-	if result.NestedCount > 0 {
-		a.logger.Infof("loading nested operator bundle(s) from %s into sqlite", result.NestedDirectory)
-		if err := a.loader.LoadBundleDirectoryToSQLite(result.NestedDirectory); err != nil {
-			errs = append(errs, err)
-		}
+	if err = a.loader.LoadBundleDirectoryToSQLite(a.downloadPath); err != nil {
+		errs = append(errs, fmt.Errorf("error loading operator manifests: %s", err))
 	}
 
 	store, err := a.loader.GetStore()
